@@ -222,7 +222,9 @@ def job_output_to_str(job_output, prefix='\n', title="Output: ", title_len=None)
                                                                    subsequent_indent=' '*9,
                                                                    break_long_words=False) for key, value in job_output.items()])
 
-def get_io_field(io_hash, defaults={}, delim='=', highlight_fields=[]):
+def get_io_field(io_hash, defaults=None, delim='=', highlight_fields=()):
+    if defaults is None:
+        defaults = {}
     if io_hash is None:
         return '-'
     if len(io_hash) == 0 and len(defaults) == 0:
