@@ -17,9 +17,12 @@
 #   License for the specific language governing permissions and limitations
 #   under the License.
 
+from __future__ import print_function
+
 import os, unittest, json, tempfile, subprocess, csv, shutil, re, time
 from dxpy import AppError
 from dxpy.utils import (describe, exec_utils, genomic_utils, response_iterator, get_futures_threadpool)
+from dxpy.compat import is_py2
 
 class TestDescribe(unittest.TestCase):
     def test_is_job_ref(self):
@@ -57,12 +60,16 @@ class TestErrorSanitizing(unittest.TestCase):
         # ASCII str
         self.assertEqual(exec_utils._safe_unicode(ValueError("foo")), "foo")
         # UTF-8 encoded str
-        self.assertEqual(exec_utils._safe_unicode(ValueError(u"crème".encode("utf-8"))), u"cr\xe8me")
+        self.assertEqual(exec_utils._safe_unicode(ValueError(u"crème".encode("utf-8"))),
+                         u"cr\xe8me" if is_py2 else u"b'cr\\xc3\\xa8me'")
         # Unicode obj
         self.assertEqual(exec_utils._safe_unicode(ValueError(u"brûlée")), u"br\xfbl\xe9e")
         # Not UTF-8
-        self.assertEqual(exec_utils._safe_unicode(ValueError(u"Invalid read name: DÑÁnèxûs".encode("ISO-8859-1"))),
-                         "Invalid read name: D??n?x?s [Raw error message: 496e76616c69642072656164206e616d653a2044d1c16ee878fb73]")
+        if is_py2:
+            expected = "Invalid read name: D??n?x?s [Raw error message: 496e76616c69642072656164206e616d653a2044d1c16ee878fb73]"
+        else:
+            expected = "b'Invalid read name: D\\xd1\\xc1n\\xe8x\\xfbs'"
+        self.assertEqual(exec_utils._safe_unicode(ValueError(u"Invalid read name: DÑÁnèxûs".encode("ISO-8859-1"))), expected)
 
     def test_formatting_exceptions(self):
         self.assertEqual(exec_utils._format_exception_message(ValueError("foo")), "ValueError: foo")
@@ -70,18 +77,19 @@ class TestErrorSanitizing(unittest.TestCase):
 
 class TestGenomicUtils(unittest.TestCase):
     def test_reverse_complement(self):
-        self.assertEqual("TTTTAAACCG", genomic_utils.reverse_complement("CGGTTTAAAA"))
-        self.assertEqual("TTTTAAACCG", genomic_utils.reverse_complement(u"CGGTTTAAAA"))
-        self.assertEqual("TTTTAAACCG", genomic_utils.reverse_complement("cggtttaaaa"))
-        self.assertEqual("TTTTAAACCG", genomic_utils.reverse_complement(u"cggtttaaaa"))
-        self.assertEqual("NNNNNTTTTAAACCG", genomic_utils.reverse_complement("CGGTTTAAAANNNNN"))
+        self.assertEqual(b"TTTTAAACCG", genomic_utils.reverse_complement(b"CGGTTTAAAA"))
+        self.assertEqual(b"TTTTAAACCG", genomic_utils.reverse_complement(u"CGGTTTAAAA"))
+        self.assertEqual(b"TTTTAAACCG", genomic_utils.reverse_complement(b"cggtttaaaa"))
+        self.assertEqual(b"TTTTAAACCG", genomic_utils.reverse_complement(u"cggtttaaaa"))
+        self.assertEqual(b"NNNNNTTTTAAACCG", genomic_utils.reverse_complement(b"CGGTTTAAAANNNNN"))
+        self.assertEqual(b"NNNNNTTTTAAACCG", genomic_utils.reverse_complement(u"CGGTTTAAAANNNNN"))
         with self.assertRaises(ValueError):
             genomic_utils.reverse_complement("oops")
 
 class TestResponseIterator(unittest.TestCase):
     def test_basic_iteration(self):
         def task(i, sleep_for=1):
-            print "Task", i, "sleeping for", sleep_for
+            print("Task", i, "sleeping for", sleep_for)
             time.sleep(sleep_for)
             return i
 
